/* $Workfile: Dsp64Def.h $   $Revision: 1 $    $Modtime: 6/16/08 11:37a $  */
#ifndef OTX64_DEF_H
#define OTX64_DEF_H
/*******************************************************************************

  @doc PublicDsp64SdkApi

  Copyright (C) 2008 Odin TeleSystems Inc., All Rights Reserved

  SAA-10xx-1 OTX DSP C64x Software Development Kit (SDK)

  Macro, Constant, and type definitions for the DSP C64x SDK API

  @module
  Dsp64Def | Constants, Macros, and Types for the DSP C64x SDK

  @contents2
  Dsp64Def.h |

  @index enum struct type | Dsp64Def

  @contents2
  Constants, Macros, and Types (Dsp64Def.h) |

  @head3 DSP C64x SDK Macro, Constant, and Type Reference |

  @index enum struct type | Dsp64Def


*******************************************************************************/

/*******************************************************************************
  MACROS
*******************************************************************************/
/* @type OTXDSP_TRUE | Boolean value TRUE */
#define OTXDSP_TRUE        1
/* @type OTXDSP_FALSE | Boolean value TRUE */
#define OTXDSP_FALSE       0

/* Companding Law Type */
/* @type OTXDSP_ULAW | U-Law Companding */
#define OTXDSP_ULAW       0
/* @type OTXDSP_ALAW | A-Law Companding */
#define OTXDSP_ALAW       1

/* @type OTXDSP_INVALID_HANDLE | Invalid Logical Device Handle Value */
#define OTXDSP_INVALID_HANDLE 0xFFFF

/* @type OTXDSP_BSP_TXBUF_SIZE | The size of the Transmit buffer for the highest    */
/* highway speed that the DSP program supports. */
/* Interrupt are generated when */
/* the buffer is full and half-full.  */
/* Note that that the size is in Words (16-bits), i.e. in multiple of two           */
/* timeslots. */
/* The processing task for the transmitter should write to the autobuffer */
/* before he hands if off to the the DMA controller or the */
/* buffered serial port for transmission. */
/* Note that this macro needs to be defined as a command line */
/* parameter to the compiler. */

/* @type OTXDSP_BSP_RXBUF_SIZE | The size of the Receive buffer for the highest */
/* highway speed that the DSP program supports. */
/* Interrupt are generated when */
/* the buffer is full and half-full. */
/* Note that that the size is in Words (16-bits), i.e. in multiple of two */
/* timeslots.  */
/* Note that this macro needs to be defined as a command line */
/* parameter to the compiler. */

/* @type OTXDSP_SDK_FRAMES_PER_BUF | Number frames in the receive and transmit */
/* buffers. The DMA controller will pick up this many frames from the receive */
/* serial port before he notifies the processing task. The same applies to the */
/* transmit DMA controller. */
/* Note that this macro needs to be defined as a command line */
/* parameter to the compiler. */


/* @type OTXDSP_HWY_SPEEDS | Supported highway speeds for this DSP program. */
/* The DSP connects to other devices via a serial port, which can be considered */
/* as a TDM highway. This macro defines the highway speeds that the DSP code supports. */
/* The macro is a bit pattern where bit0=2048kpbs, bit1=4096kpbs, and bit2=8192kpbs.  */
/* Setting any of these three bits to 1 specifies that this highway speed is supported */
/* by this DSP program. If this macro is not defined on the command line, it is set to */
/* 0x0001 (2048kpbs) in the Dsp54Api.c code. */

/* @type OTXDSP_HWY_SPEED_2M | Highway speed 2048 kpbs is supported for this DSP program. */
#define OTXDSP_HWY_SPEED_2M 0x0001

/* @type OTXDSP_HWY_SPEED_4M | Highway speed 4096 kpbs is supported for this DSP program. */
#define OTXDSP_HWY_SPEED_4M 0x0002

/* @type OTXDSP_HWY_SPEED_8M | Highway speed 8192 kpbs is supported for this DSP program. */
#define OTXDSP_HWY_SPEED_8M 0x0004


/* @type OTXDSP_NO_TASKREF | No Task Reference */
#define OTXDSP_NO_TASKREF  0xFFFF



/*******************************************************************************
  TYPES
*******************************************************************************/
struct OtxDspHpiEventBufDiag {
  unsigned short cwFreeBuffer;    // @field Current number of free words in the HPI Event Buffer
  unsigned short cwMinFreeBuffer; // @field Minimum number of free words in the HPI Event Buffer since the application started
  unsigned short coLostEvents;    // @field Number of lost event packets (due to a full buffer) since the application started
};

// @type OtxDspHpiDiag | Struct for diagnostics of the HPI Event buffer (events passed from the DSP to the host)
typedef struct OtxDspHpiEventBufDiag OtxDspHpiEventBufDiag;

struct OtxDspTimeStamp {
  unsigned short nHighPart;  // @field Bit 48-63
  unsigned short nMidPart;   // @field Bit 32-47
  unsigned short nLowPart;   // @field Bit 16-31
};

// @type OtxDspTimeStamp | Struct used for passing a 64 bit timestamp for each HPI Event
typedef struct OtxDspTimeStamp OtxDspTimeStamp;

/*******************************************************************************
  GLOBAL VARIABLES
*******************************************************************************/

extern unsigned short g_nHighwaySpeed;
extern unsigned short g_nTimeslotsPerFrame;
extern unsigned short g_nWordslotsPerFrame;

extern OtxDspHpiEventBufDiag g_hpiEventBufDiag;
extern OtxDspTimeStamp g_timeStamp;

extern volatile short g_bGotDmaRxInterrupt;
extern volatile short g_bGotDmaTxInterrupt;
extern volatile short g_bGotHostPortInterrupt;

extern volatile unsigned short g_nFrameBufferCounter;

//extern Uint32 g_nRevtCounter;
//extern Uint32 g_nXevtCounter;
//extern Uint16 g_nDmaRxTimeoutCounter;
//extern Uint16 g_nDmaRxDropCounter;
//extern Uint16 g_nDmaTxTimeoutCounter;
//extern Uint16 g_nDmaTxDropCounter;


/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2008


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/

#endif /* OTX64_DEF_H */

